@@ -7,7 +7,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02'; # TRIAL
+our $VERSION = '0.03'; # TRIAL
 
 use overload ();
 use Carp;
@@ -177,7 +177,7 @@ sub import {
         if ( $arg eq '-not' ) {
 
 	    # if first is an exclusion, populate
-            @install{ _ops( ':all' ) } = 1
+            @install{ $class->_ops( ':all' ) } = 1
 		if @args == @_ - 1;
 
             $arg = shift @args
@@ -185,17 +185,17 @@ sub import {
 
 	    $arg = [ $arg ] unless 'ARRAY' eq ref $arg;
 
-            delete @install{ _ops( $_ ) } foreach @$arg
+            delete @install{ $class->_ops( $_ ) } foreach @$arg
         }
         else {
-            @install{ _ops( $arg ) } = 1;
+            @install{ $class->_ops( $arg ) } = 1;
         }
     }
 
     # default to all if not specified, but only if no arguments were
     # passed. that way if the caller (mistakenly?) excludes everything
     # it gets what it asks for.
-    @install{ _ops( ':all' ) } = 1
+    @install{ $class->_ops( ':all' ) } = 1
 	unless %install || @_;
 
     for my $op ( keys %install ) {
@@ -245,33 +245,73 @@ sub import {
     }
 }
 
-sub _ops {
+#pod =method tag_to_ops
+#pod
+#pod   @ops = overload::reify->tag_to_ops( $tag );
+#pod
+#pod Return a list of operators correspond to the passed tag.  A tag is a string which
+#pod is either
+#pod
+#pod =over
+#pod
+#pod =item *
+#pod
+#pod an operator, e.g. C<'++'>; or
+#pod
+#pod =item *
+#pod
+#pod a string (in the form C<:>I<class>) representing a class
+#pod of operators. A class may be any of the keys accepted by the
+#pod L<overload|overload/Overloadable Operations> pragma, as well as the
+#pod special class C<all>, which consists of all operators.
+#pod
+#pod =back
+#pod
+#pod =cut
 
-    my ( $op ) = @_;
+sub tag_to_ops {
+
+    my ( $class, $op ) = @_;
 
     return $op if defined $OP{$op};
     return keys %OP if $op eq ':all';
 
     my ( $tag ) = $op =~ /^:(.*)$/;
 
-    return grep( $_ ne 'fallback', $overload::ops{$tag} )
+    return grep( $_ ne 'fallback', split( /\s+/, $overload::ops{$tag} ) )
       if defined $overload::ops{$tag};
 
-    croak( "unknown operator or tag: $op\n" );
     return;
 }
 
+sub _ops {
+
+    my ( $class, $op ) = @_;
+
+    my @ops = $class->tag_to_ops( $op );
+
+    croak( "unknown operator or tag: $op\n" )
+      unless @ops;
+
+    return @ops;
+}
+
 #pod =method method_names
 #pod
 #pod   # from the command line:
 #pod   perl -Ilib -MData::Dumper -Moverload::reify \
 #pod      -e 'print Dumper overload::reify->method_names()'
 #pod
-#pod   # in code 
-#pod   $hashref = overload::reify->method_names( %options );
+#pod   # in code
+#pod   $hashref = overload::reify->method_names( ?@ops, ?\%options );
 #pod
-#pod This class method returns a hashref whose keys are operators and whose
-#pod values are the names of generated methods.  The available options are:
+#pod This class method retuns the mapping between operators and generated
+#pod method names.  Supplied operators are first run through
+#pod L</tag_to_ops>.  If no operators are passed, a map for all of the
+#pod supported ones is returned.
+#pod
+#pod The map is returned a hashref whose keys are operators and whose
+#pod values are the names of generated methods. The available options are:
 #pod
 #pod =over
 #pod
@@ -288,9 +328,13 @@ sub method_names {
 
     my $class = shift;
 
-    my %opt = ( -prefix => 'operator_', @_ );
+    my %opt = ( -prefix => 'operator_',
+		'HASH' eq ref $_[-1] ? %{ pop() } : (),
+	      );
 
-    return { map +($_ => $opt{-prefix} . $OP{$_}), keys %OP };
+    my @ops = @_ ? map $class->tag_to_ops( $_ ), @_ : keys %OP;
+
+    return { map +($_ => $opt{-prefix} . $OP{$_}), @ops };
 };
 
 
@@ -313,7 +357,7 @@ overload::reify - Provide named methods for inherited overloaded operators
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -446,17 +490,44 @@ C<operator_>.
 
 =head1 METHODS
 
+=head2 tag_to_ops
+
+  @ops = overload::reify->tag_to_ops( $tag );
+
+Return a list of operators correspond to the passed tag.  A tag is a string which
+is either
+
+=over
+
+=item *
+
+an operator, e.g. C<'++'>; or
+
+=item *
+
+a string (in the form C<:>I<class>) representing a class
+of operators. A class may be any of the keys accepted by the
+L<overload|overload/Overloadable Operations> pragma, as well as the
+special class C<all>, which consists of all operators.
+
+=back
+
 =head2 method_names
 
   # from the command line:
   perl -Ilib -MData::Dumper -Moverload::reify \
      -e 'print Dumper overload::reify->method_names()'
 
-  # in code 
-  $hashref = overload::reify->method_names( %options );
+  # in code
+  $hashref = overload::reify->method_names( ?@ops, ?\%options );
 
-This class method returns a hashref whose keys are operators and whose
-values are the names of generated methods.  The available options are:
+This class method retuns the mapping between operators and generated
+method names.  Supplied operators are first run through
+L</tag_to_ops>.  If no operators are passed, a map for all of the
+supported ones is returned.
+
+The map is returned a hashref whose keys are operators and whose
+values are the names of generated methods. The available options are:
 
 =over
 
